Struct amazon_sp_aplus_content::models::standard_single_image_specs_detail_module::StandardSingleImageSpecsDetailModule
source · [−]pub struct StandardSingleImageSpecsDetailModule {
pub headline: Option<Box<TextComponent>>,
pub image: Option<Box<ImageComponent>>,
pub description_headline: Option<Box<TextComponent>>,
pub description_block1: Option<Box<StandardTextBlock>>,
pub description_block2: Option<Box<StandardTextBlock>>,
pub specification_headline: Option<Box<TextComponent>>,
pub specification_list_block: Option<Box<StandardHeaderTextListBlock>>,
pub specification_text_block: Option<Box<StandardTextBlock>>,
}Expand description
StandardSingleImageSpecsDetailModule : A standard image with paragraphs and a bulleted list, and extra space for technical details.
Fields
headline: Option<Box<TextComponent>>image: Option<Box<ImageComponent>>description_headline: Option<Box<TextComponent>>description_block1: Option<Box<StandardTextBlock>>description_block2: Option<Box<StandardTextBlock>>specification_headline: Option<Box<TextComponent>>specification_list_block: Option<Box<StandardHeaderTextListBlock>>specification_text_block: Option<Box<StandardTextBlock>>Implementations
sourceimpl StandardSingleImageSpecsDetailModule
impl StandardSingleImageSpecsDetailModule
sourcepub fn new() -> StandardSingleImageSpecsDetailModule
pub fn new() -> StandardSingleImageSpecsDetailModule
A standard image with paragraphs and a bulleted list, and extra space for technical details.